==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," '");
define("_SORTASC","  ");
define("_SORTDESC","  ");

define("_CANCEL","³");
define("_YES","");
define("_NO","ͳ");

define("_SCORE",":");

define("_REPLYMAIN"," ");
define("_ALLOWEDHTML"," HTML-:");
define("_POSTANON","³ ");
define("_WRITEREVIEW"," ");
define("_WRITEREVIEWFOR","  ");
define("_ENTERINFO","    ");
define("_PRODUCTTITLE","");
define("_NAMEPRODUCT"," .");
define("_REVIEW","");
define("_CHECKREVIEW"," .  ,    !     HTML-.");
define("_FULLNAMEREQ"," '  . '.");
define("_REMAIL"," Email");
define("_REMAILREQ"," Email . '.");
define("_SELECTSCORE"," ");
define("_RELATEDLINK"," ");
define("_PRODUCTSITE"," .    URL   \"http://\"");
define("_LINKTITLE"," ");
define("_LINKTITLEREQ",",    .");
define("_RIMAGEFILE","'  ");
define("_RIMAGEFILEREQ"," ,   images/reviews/.  '.");
define("_CHECKINFO"," , ,      100%.      ,   .");
define("_INVALIDTITLE","  (   ).");
define("_INVALIDSCORE","  ( 1  10)");
define("_INVALIDTEXT","  .");
define("_INVALIDHITS","    .");
define("_CHECKNAME","    '  email.");
define("_INVALIDEMAIL"," email.");
define("_INVALIDLINK","        .");
define("_ADDED",":");
define("_REVIEWER",":");
define("_REVIEWID","ID ");
define("_HITS","ճ");
define("_LOOKSRIGHT","  ?");
define("_RMODIFIED","");
define("_RADDED","");

define("_ADMINLOGGED","   .     .");
define("_RTHANKS","   !");
define("_MODIFICATION","");
define("_ISAVAILABLE","     .");
define("_EDITORWILLLOOK","   .    .");
define("_RBACK","   ");
define("_RWELCOME","    ");
define("_10MOSTPOP","10   ");
define("_10MOSTREC","10   ");
define("_THEREARE","");
define("_REVIEWSINDB","   ");
define("_REVIEWS","");
define("_REVIEWSLETTER"," ");
define("_NOREVIEWS","  ");
define("_TOTALREVIEWS","  .");
define("_RETURN2MAIN","   ");
define("_REVIEWCOMMENT"," :");
define("_YOURNICK"," ':");
define("_RCREATEACCOUNT","<a href=user.php></a> ");
define("_YOURCOMMENT"," :");
define("_MYSCORE"," :");

define("_REVIEWMOD","  ");
define("_RDATE",":");
define("_RTITLE",":");
define("_RTEXT",":");
define("_REVEMAIL","Email:");
define("_RLINK",":");
define("_RLINKTITLE"," :");
define("_COVERIMAGE",":");
define("_PREMODS","  ");
define("_PAGE","");
define("_PAGEBREAK","    ,    <b>&lt;!--pagebreak--&gt;</b> ,   .");
define("_PREVIEW"," ");
define("_LANGUAGE","Language");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," '");
define("_SORTASC","  ");
define("_SORTDESC","  ");

define("_CANCEL","³");
define("_YES","");
define("_NO","ͳ");

define("_SCORE",":");

define("_REPLYMAIN"," ");
define("_ALLOWEDHTML"," HTML-:");
define("_POSTANON","³ ");
define("_WRITEREVIEW"," ");
define("_WRITEREVIEWFOR","  ");
define("_ENTERINFO","    ");
define("_PRODUCTTITLE","");
define("_NAMEPRODUCT"," .");
define("_REVIEW","");
define("_CHECKREVIEW"," .  ,    !     HTML-.");
define("_FULLNAMEREQ"," '  . '.");
define("_REMAIL"," Email");
define("_REMAILREQ"," Email . '.");
define("_SELECTSCORE"," ");
define("_RELATEDLINK"," ");
define("_PRODUCTSITE"," .    URL   \"http://\"");
define("_LINKTITLE"," ");
define("_LINKTITLEREQ",",    .");
define("_RIMAGEFILE","'  ");
define("_RIMAGEFILEREQ"," ,   images/reviews/.  '.");
define("_CHECKINFO"," , ,      100%.      ,   .");
define("_INVALIDTITLE","  (   ).");
define("_INVALIDSCORE","  ( 1  10)");
define("_INVALIDTEXT","  .");
define("_INVALIDHITS","    .");
define("_CHECKNAME","    '  email.");
define("_INVALIDEMAIL"," email.");
define("_INVALIDLINK","        .");
define("_ADDED",":");
define("_REVIEWER",":");
define("_REVIEWID","ID ");
define("_HITS","ճ");
define("_LOOKSRIGHT","  ?");
define("_RMODIFIED","");
define("_RADDED","");

define("_ADMINLOGGED","   .     .");
define("_RTHANKS","   !");
define("_MODIFICATION","");
define("_ISAVAILABLE","     .");
define("_EDITORWILLLOOK","   .    .");
define("_RBACK","   ");
define("_RWELCOME","    ");
define("_10MOSTPOP","10   ");
define("_10MOSTREC","10   ");
define("_THEREARE","");
define("_REVIEWSINDB","   ");
define("_REVIEWS","");
define("_REVIEWSLETTER"," ");
define("_NOREVIEWS","  ");
define("_TOTALREVIEWS","  .");
define("_RETURN2MAIN","   ");
define("_REVIEWCOMMENT"," :");
define("_YOURNICK"," ':");
define("_RCREATEACCOUNT","<a href=user.php></a> ");
define("_YOURCOMMENT"," :");
define("_MYSCORE"," :");

define("_REVIEWMOD","  ");
define("_RDATE",":");
define("_RTITLE",":");
define("_RTEXT",":");
define("_REVEMAIL","Email:");
define("_RLINK",":");
define("_RLINKTITLE"," :");
define("_COVERIMAGE",":");
define("_PREMODS","  ");
define("_PAGE","");
define("_PAGEBREAK","    ,    <b>&lt;!--pagebreak--&gt;</b> ,   .");
define("_PREVIEW"," ");
define("_LANGUAGE","Language");

?>
